@@ -9,9 +9,12 @@
 
 class vscreen_widget;
 
+template<class T> class ref_ptr;
+
+typedef ref_ptr<vscreen_widget> vs_widget_ref;
 // hmm, maybe just make this a global variable that gets shown and hidden?
-vscreen_widget *make_ui_options_dialog();
-vscreen_widget *make_misc_options_dialog();
-vscreen_widget *make_dependency_options_dialog();
+vs_widget_ref make_ui_options_dialog();
+vs_widget_ref make_misc_options_dialog();
+vs_widget_ref make_dependency_options_dialog();
 
 #endif
