@@ -6,7 +6,8 @@
 
 #include <aptitude.h>
 
-#include <generic/apt.h>
+#include <generic/apt/apt.h>
+#include <generic/apt/config_signal.h>
 
 #include <apt-pkg/error.h>
 
@@ -17,7 +18,7 @@ int cmdline_forget_new(int argc, char *argv[],
 {
   _error->DumpErrors();
 
-  OpTextProgress progress;
+  OpTextProgress progress(aptcfg->FindI("Quiet", 0));
 
   apt_init(&progress, false, status_fname);
 
