@@ -1,6 +1,6 @@
 // cmdline_resolver.cc
 //
-//   Copyright (C) 2005 Daniel Burrows
+//   Copyright (C) 2005-2006 Daniel Burrows
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -91,7 +91,7 @@ static void setup_resolver(pkgset &to_install,
   if(force_no_change && resman->resolver_exists())
     {
       pkgset *sets[4]={&to_install, &to_hold, &to_remove, &to_purge};
-      int tweak_amt=aptcfg->FindI(PACKAGE "::CmdLine::Request-Strictness", 0);
+      int tweak_amt=aptcfg->FindI(PACKAGE "::CmdLine::Request-Strictness", 10000);
 
       for(int i=0; i<4; ++i)
 	{
@@ -584,8 +584,10 @@ bool cmdline_resolve_deps(pkgset &to_install,
 		  case '=':
 		  case '_':
 		  case ':':
+		    /// \todo Maybe only do auto-installation of dependencies
+		    /// after the parse?
 		    cmdline_parse_action(response, to_install, to_hold,
-					 to_remove, to_purge, verbose);
+					 to_remove, to_purge, verbose, false);
 		    modified_pkgs=true;
 		    break;
 		    // Undocumented debug feature:
@@ -617,7 +619,7 @@ bool cmdline_resolve_deps(pkgset &to_install,
 		while(!done)
 		  {
 		    string response;
-
+// FIXME: translate Y, N
 		    if(!assume_yes)
 		      response = prompt_string(_("No solution found within the allotted time.  Try harder? [Y/n]"));
 
@@ -629,6 +631,7 @@ bool cmdline_resolve_deps(pkgset &to_install,
 			loc=0;
 			response='Y';
 		      }
+// FIXME: translate Y, N
 		    switch(toupper(response[loc]))
 		      {
 		      case 'Y':
