@@ -1,6 +1,6 @@
 // desc_parse.cc
 //
-//  Copyright 2004-2005 Daniel Burrows
+//  Copyright 2004-2006 Daniel Burrows
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -24,6 +24,8 @@
 #include "aptitude.h"
 #include "ui.h"
 
+#include <generic/apt/apt.h>
+#include <generic/apt/config_signal.h>
 #include <generic/apt/tags.h>
 
 #include <vscreen/fragment.h>
@@ -39,9 +41,15 @@ using namespace std;
 // list.  Every succeeding line that begins with N+1 or more spaces,
 // where N is the number of spaces preceding the bullet, is considered
 // to be part of the same bulleted list, and is processed as if N+1
-// spaces had been stripped from its left margin, with the exception
-// that if the N+2nd character is not a space, the line is formatted
-// as if a leading space were present.  (see below)
+// spaces had been stripped from its left margin, with two exceptions:
+//
+//   * if the N+2nd character is not a space, the line is formatted as
+//     if a leading space were present.  (see below)
+//   * lines containing a space followed by a full stop terminate a
+//     paragraph but do NOT break the list.
+//   * Full stops at the beginning of a line of the list are ignored
+//     (even though shifting them left would put them at the front
+//     of a line).
 //
 //   Bullet characters are (maybe) "-", "+", and "*"; the
 // frontend may render them literally or modify their appearence as it
@@ -69,7 +77,8 @@ using namespace std;
 static fragment *make_level_fragment(const wstring &desc,
 				     unsigned int level,
 				     wstring::size_type indent,
-				     wstring::size_type &start)
+				     wstring::size_type &start,
+				     bool recognize_bullets)
 {
   vector<fragment*> fragments;
   bool first=true;
@@ -89,7 +98,15 @@ static fragment *make_level_fragment(const wstring &desc,
 	      ++nspaces;
 	    }
 
-	  if(nspaces<indent)
+	  // This handles the case of " .\n" breaking list paragraphs.
+	  // I arbitrarily put the paragraph break inside the indented
+	  // text even when it actually terminates the list.
+	  if(nspaces == 1 && loc < desc.size() && desc[loc] == L'.')
+	    ; // Handled uniformly below for both this case and the
+	      // case of a leading blank line.
+	  else if(nspaces < indent) // Anything but a " .\n" that has
+				    // the wrong indent will break the
+				    // list.
 	    break;
 	}
       else
@@ -98,6 +115,23 @@ static fragment *make_level_fragment(const wstring &desc,
 	  first=false;
 	}
 
+      // Only insert blank lines for full stops that have exactly one
+      // space; other full stops are treated as part of a paragraph.
+      if(nspaces == 1 && desc[loc] == '.')
+	{
+	  fragments.push_back(newline_fragment());
+
+	  while(loc < desc.size() && desc[loc] != L'\n')
+	    ++loc;
+
+	  if(loc < desc.size())
+	    ++loc;
+
+	  start=loc;
+
+	  continue; // Skip the switch statement below.
+	}
+
       switch(desc[loc])
 	{
 	case L' ':
@@ -117,29 +151,25 @@ static fragment *make_level_fragment(const wstring &desc,
 		++nspaces2;
 	      }
 
-	    if(loc2<desc.size() &&
+	    if(recognize_bullets &&
+	       loc2 + 1 < desc.size() &&
 	       (desc[loc2] == L'+' ||
 		desc[loc2] == L'-' ||
-		desc[loc2] == L'*'))
+		desc[loc2] == L'*') &&
+	       desc[loc2 + 1] == L' ')
 	      {
 		// Start a list item (i.e., an indented region).
 
 		wstring bullet;
 		bullet+=(L"*+-"[level%3]);
 
-		start = loc2+1;
-		int indent_beyond_bullet = 0;
-
-		while(start < desc.size() && desc[start] == L' ')
-		  {
-		    ++start;
-		    ++indent_beyond_bullet;
-		  }
+		start = loc2 + 2;
 
 		fragment *item_contents=make_level_fragment(desc,
 							    level+1,
-							    nspaces2 + 1 + indent_beyond_bullet,
-							    start);
+							    nspaces2 + 2,
+							    start,
+							    recognize_bullets);
 
 		fragments.push_back(style_fragment(text_fragment(bullet),
 						   get_style("Bullet")));
@@ -166,20 +196,6 @@ static fragment *make_level_fragment(const wstring &desc,
 	  }
 
 	  break;
-	case L'.':
-	  // Add a blank line (ignore the rest of the line)
-	  {
-	    fragments.push_back(newline_fragment());
-
-	    while(loc<desc.size() && desc[loc]!=L'\n')
-	      ++loc;
-
-	    if(loc<desc.size())
-	      ++loc;
-
-	    start=loc;
-	    break;
-	  }
 	default:
 	  // It's a paragraph.
 	  {
@@ -225,7 +241,7 @@ static fragment *make_level_fragment(const wstring &desc,
 		cont=false;
 	      else if(loc>=desc.size())
 		cont=false;
-	      else if(desc[loc]=='.')
+	      else if(nspaces == 1 && desc[loc] == '.')
 		cont=false;
 	    } while(cont);
 
@@ -254,7 +270,9 @@ fragment *make_desc_fragment(const wstring &desc)
     ++loc;
 
   // Note that the starting amount of indentation is 1...
-  return make_level_fragment(desc, 0, 1, loc);
+  return make_level_fragment(desc, 0, 1, loc,
+			     aptcfg->FindB(PACKAGE "::Parse-Description-Bullets",
+					   true));
 }
 
 
