@@ -1,6 +1,6 @@
 // download_bar.cc
 //
-//  Copyright 1999,2000 Daniel Burrows
+//  Copyright 1999-2000, 2004-2005 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -24,8 +24,10 @@
 
 #include <vscreen/config/keybindings.h>
 #include <vscreen/config/colors.h>
+#include <vscreen/fragment.h>
 #include <vscreen/vs_minibuf_win.h>
 #include <vscreen/vs_util.h>
+#include <vscreen/transcode.h>
 
 #include <apt-pkg/strutl.h>
 #include <apt-pkg/acquire-item.h>
@@ -33,35 +35,25 @@
 
 #include <signal.h>
 
-#define CRITICAL_ENTER	\
-  vscreen_acquirelock();\
-  sigset_t ___signals,___oldset;\
-  sigemptyset(&___signals);	\
-  sigaddset(&___signals, SIGWINCH);\
-  sigprocmask(SIG_BLOCK, &___signals, &___oldset);\
-  assert(!sigismember(&___oldset, SIGWINCH));
+#include <sigc++/functors/ptr_fun.h>
 
-#define CRITICAL_EXIT	\
-  sigprocmask(SIG_SETMASK, &___oldset, &___signals);\
-  assert(sigismember(&___signals, SIGWINCH));\
-  vscreen_releaselock();
+
+download_status_bar::download_status_bar()
+{
+}
 
 bool download_status_bar::MediaChange(string media, string drive)
 {
-  CRITICAL_ENTER
+  vs_widget_ref tmpref(this);
 
-  char buf[512];
-  snprintf(buf, 512,
-	   _("Please insert the following disc into the drive \"%s\":\n%s"),
-	   drive.c_str(), media.c_str());
+  fragment *f=wrapbox(fragf(_("Please insert the disc labeled \"%s\" into the drive \"%s\""),
+			      media.c_str(), drive.c_str()));
 
-  vscreen_widget *w=vs_dialog_ok(buf, SigC::slot(vscreen_exitmain),
-				 get_color("MediaChange"));
+  vs_widget_ref w = vs_dialog_ok(f, arg(sigc::ptr_fun(vscreen_exitmain)),
+				 get_style("MediaChange"));
   w->show_all();
   popup_widget(w);
 
-  CRITICAL_EXIT
-
   vscreen_mainloop();  // Eeeeeek!  Recursive mainloop!  I'm afraid..
 
   return true;
@@ -69,64 +61,56 @@ bool download_status_bar::MediaChange(string media, string drive)
 
 void download_status_bar::IMSHit(pkgAcquire::ItemDesc &itm)
 {
-  CRITICAL_ENTER
+  vs_widget_ref tmpref(this);
 
   last_msg=_("Hit ")+itm.Description;
   last_switchtime=time(0);
 
   vscreen_update();
   vscreen_tryupdate();
-
-  CRITICAL_EXIT
 }
 
 void download_status_bar::Fetch(pkgAcquire::ItemDesc &itm)
 {
-  CRITICAL_ENTER
+  vs_widget_ref tmpref(this);
 
   last_msg=_("Downloading ")+itm.ShortDesc;
   last_switchtime=time(0);
 
   vscreen_update();
   vscreen_tryupdate();
-
-  CRITICAL_EXIT
 }
 
 void download_status_bar::Done(pkgAcquire::ItemDesc &itm)
 {
-  CRITICAL_ENTER
+  vs_widget_ref tmpref(this);
 
   last_msg=_("Got ")+itm.Description;
   last_switchtime=time(0);
 
   vscreen_update();
   vscreen_tryupdate();
-
-  CRITICAL_EXIT
 }
 
 void download_status_bar::Fail(pkgAcquire::ItemDesc &itm)
 {
-  CRITICAL_ENTER
+  vs_widget_ref tmpref(this);
 
   last_msg=itm.Description+": "+itm.Owner->ErrorText;
   last_switchtime=time(0);
 
   vscreen_update();
   vscreen_tryupdate();
-
-  CRITICAL_EXIT
 }
 
 bool download_status_bar::Pulse(pkgAcquire *Owner)
 {
+  vs_widget_ref tmpref(this);
+
   pkgAcquireStatus::Pulse(Owner);
 
   if(difftime(time(0), last_switchtime)>1)
     {
-      CRITICAL_ENTER
-
       pkgAcquire::Worker *test=Owner->WorkersBegin();
       bool found=false;
       while(test)
@@ -173,15 +157,15 @@ bool download_status_bar::Pulse(pkgAcquire *Owner)
 
       vscreen_update();
       vscreen_tryupdate();
-
-      CRITICAL_EXIT
     }
 
   return !cancelled;
 }
 
-void download_status_bar::paint()
+void download_status_bar::paint(const style &st)
 {
+  vs_widget_ref tmpref(this);
+
   int width=getmaxx();
   string todisp=last_msg,totalprogress;
 
@@ -212,32 +196,34 @@ void download_status_bar::paint()
 
   show_string_as_progbar(0,
 			 0,
-			 todisp,
-			 get_color("Progress"),
-			 get_color("ScreenStatusColor"),
+			 transcode(todisp),
+			 st+get_style("Progress"),
+			 st+get_style("Status"),
 			 barsize,
 			 width);
 }
 
 void download_status_bar::Start()
 {
+  vs_widget_ref tmpref(this);
+
   pkgAcquireStatus::Start();
 }
 
 void download_status_bar::Stop()
 {
-  CRITICAL_ENTER
+  vs_widget_ref tmpref(this);
 
   pkgAcquireStatus::Stop();
 
   destroy();
-
-  CRITICAL_EXIT
 }
 
-bool download_status_bar::handle_char(chtype ch)
+bool download_status_bar::handle_key(const key &k)
 {
-  if(global_bindings.key_matches(ch, "Quit"))
+  vs_widget_ref tmpref(this);
+
+  if(global_bindings.key_matches(k, "Quit"))
     {
       cancelled=true;
       return true;
@@ -246,7 +232,12 @@ bool download_status_bar::handle_char(chtype ch)
     return false;
 }
 
-size download_status_bar::size_request()
+int download_status_bar::width_request()
 {
-  return size(0,0);
+  return 0;
+}
+
+int download_status_bar::height_request(int)
+{
+  return 0;
 }
