@@ -1,6 +1,6 @@
 // download_item.h -- this is -*-c++-*-
 //
-//  Copyright 1999 Daniel Burrows
+//  Copyright 1999-2001, 2005 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -42,15 +42,17 @@ class download_item:public vs_treeitem
 public:
   download_item(const pkgAcquire::ItemDesc &_item):vs_treeitem(false), item(_item), worker(NULL) {}
 
-  int get_normal_attr();
+  style get_normal_style();
 
-  virtual void paint(vs_tree *win, int y, bool hierarchical);
+  virtual void paint(vs_tree *win, int y, bool hierarchical,
+		     const style &st);
 
   void download_done(bool _hit) {hit=_hit;}
   void set_worker(pkgAcquire::Worker *_worker) {worker=_worker;}
 
-  const char *tag() const {return item.Description.c_str();}
-  const char *label() const {return item.Description.c_str();}
+  // Nothing sensible to return here.
+  const wchar_t *tag() {return L"";}
+  const wchar_t *label() {return L"";}
 };
 
 #endif
