@@ -1,6 +1,6 @@
 // aptcache.cc
 //
-//  Copyright 1999-2005 Daniel Burrows
+//  Copyright 1999-2006 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -230,7 +230,7 @@ bool aptitudeDepCache::build_selection_list(OpProgress &Prog, bool WithLock,
 
   if(WithLock && lock==-1)
     {
-      lock=GetLock(statedir+"lock");
+      lock = GetLock(aptcfg->Find("Aptitude::LockFile", LOCKFILE));
 
       if(_error->PendingError())
 	{
@@ -360,7 +360,7 @@ bool aptitudeDepCache::build_selection_list(OpProgress &Prog, bool WithLock,
 
 	  // FIXME: should I check this for "unknown" packages as well?
 	  // Does that even make sense??
-	  if(!estate.candver.empty() && estate.upgrade)
+	  if(!estate.candver.empty())
 	    {
 	      for(pkgCache::VerIterator ver=i.VersionList(); !ver.end(); ++ver)
 		if(ver.VerStr()==estate.candver &&
@@ -557,7 +557,8 @@ bool aptitudeDepCache::save_selection_list(OpProgress &prog,
 
 	    if(state.Install() &&
 	       !estate.candver.empty() &&
-	       GetCandidateVer(i).VerStr() != estate.candver)
+	       (GetCandidateVer(i).end() ||
+		GetCandidateVer(i).VerStr() != estate.candver))
 	      tailstr = "Version: " + estate.candver + "\n";
 
 	    len=snprintf(buf,
@@ -1454,7 +1455,7 @@ void aptitudeDepCache::mark_and_sweep(undo_group *undo)
 
   mark_and_sweep_in_progress=true;
 
-  std::string matchterm = aptcfg->Find(PACKAGE "::Keep-Unused-Pattern", "");
+  std::string matchterm = aptcfg->Find(PACKAGE "::Keep-Unused-Pattern", "~nlinux-image-.*");
   if(matchterm.empty()) // Bug-compatibility with old versions.
     matchterm = aptcfg->Find(PACKAGE "::Delete-Unused-Pattern", "");
   pkg_matcher *matcher=matchterm.empty()?NULL:parse_pattern(matchterm);
