@@ -39,7 +39,7 @@
 #ifndef PROBLEMRESOLVER_H
 #define PROBLEMRESOLVER_H
 
-#include <assert.h>
+#include <generic/util/eassert.h>
 
 #include <algorithm>
 #include <map>
@@ -48,6 +48,7 @@
 #include <vector>
 
 #include <iostream>
+#include <sstream>
 
 #include "dump_universe.h"
 #include "exceptions.h"
@@ -508,7 +509,7 @@ private:
     ~instance_tracker()
     {
       threads::mutex::lock l(r.execution_mutex);
-      assert(r.solver_executing);
+      eassert(r.solver_executing);
 
       r.solver_executing = false;
       r.solver_cancelled = false;
@@ -1024,7 +1025,7 @@ private:
 
     void install(const package &p, const version &v)
     {
-      assert(installations.find(p) == installations.end());
+      eassert(installations.find(p) == installations.end());
 
       installations[p]=v;
     }
@@ -1252,7 +1253,7 @@ private:
 
     while(!broken_deps.empty())
       {
-	assert(!avail_versions.empty());
+	eassert(!avail_versions.empty());
 
 	// Pick an "arbitrary" broken dependency.
 	dep d = *broken_deps.begin();
@@ -1283,9 +1284,9 @@ private:
 
 	// I have a proof that a solver should exist, but that doesn't
 	// mean it does ;-)
-	assert(found_one);
-	assert(output_actions.find(solver.get_package()) == output_actions.end());
-	assert(solver != solver.get_package().current_version());
+	eassert(found_one);
+	eassert(output_actions.find(solver.get_package()) == output_actions.end());
+	eassert(solver != solver.get_package().current_version());
 
 	if(debug)
 	  std::cout << "Filter: resolving " << d << " with "
@@ -1334,7 +1335,7 @@ private:
    */
   solution eliminate_stupid(const solution &s)
   {
-    assert(s.get_broken().empty());
+    eassert(s.get_broken().empty());
 
     stupid_table stupid_pairs;
 
@@ -1397,7 +1398,7 @@ private:
 			<< first_broken << std::endl;
 
 	    typename std::map<package, action>::const_iterator found = rval.get_actions().find(victim.first.get_package());
-	    assert(found != rval.get_actions().end());
+	    eassert(found != rval.get_actions().end());
 
 	    action repl_action(victim.first, first_broken,
 			       found->second.id);
@@ -1469,7 +1470,7 @@ private:
 	  }
       }
 
-    assert(rval.get_broken().empty());
+    eassert(rval.get_broken().empty());
 
     return rval;
   }
@@ -1763,7 +1764,7 @@ private:
       }
     else
       {
-	assert(v != cur);
+	eassert(v != cur);
 
 	typename imm::map<version, dep>::node found
 	  = s.get_forbidden_versions().lookup(v);
@@ -1807,11 +1808,11 @@ private:
 
 	action a2 = act;
 
-	assert(found_act.ver == act.ver);
+	eassert(found_act.ver == act.ver);
 	if(a2.from_dep_source)
 	  {
 	    if(found_act.from_dep_source)
-	      assert(a2.d == found_act.d);
+	      eassert(a2.d == found_act.d);
 
 	    else
 	      a2.from_dep_source = false;
@@ -1959,7 +1960,7 @@ private:
 		if(ci->first != v.get_package())
 		  insert_conflictor(conflict, ci->second);
 		else
-		  assert(ci->second.ver == v);
+		  eassert(ci->second.ver == v);
 	      }
 	  }
       }
@@ -1990,7 +1991,7 @@ private:
       insert_conflictor(conflict, action(source, d, false, -1));
     else
       {
-	assert(source == source.get_package().current_version());
+	eassert(source == source.get_package().current_version());
 
 	for(typename package::version_iterator vi = source.get_package().versions_begin();
 	    !vi.end(); ++vi)
@@ -2019,7 +2020,10 @@ private:
     // forcings are performed ASAP.
     solution curr = s;
 
-    assert(!s.get_broken().empty());
+    eassert(!s.get_broken().empty());
+
+    // Set to \b true if this search node is untenable.
+    bool dead_end = false;
 
     // This loop attempts to generate all the successors of a
     // solution.  However, if a "forced" dependency arises, it
@@ -2054,24 +2058,26 @@ private:
 	    // something is broken elsewhere).
 	    if(starting_solution == curr && !(*bi).broken_under(curr))
 	      {
-		std::cerr << "Unexpectedly non-broken dependency "
-			  << *bi << "!" << std::endl;
+		std::ostringstream msg;
+
+		msg << "Unexpectedly non-broken dependency "
+		    << *bi << "!" << std::endl;
 
 		version source = (*bi).get_source();
 
 		if(curr.version_of(source.get_package()) != source)
-		  std::cerr << "  (" << source.get_package().get_name()
-			    << " " << source.get_name()
-			    << " is not installed)" << std::endl;
+		  msg << "  (" << source.get_package().get_name()
+		      << " " << source.get_name()
+		      << " is not installed)" << std::endl;
 
 		for(typename dep::solver_iterator si = (*bi).solvers_begin();
 		    !si.end(); ++si)
 		  if(curr.version_of((*si).get_package()) == *si)
-		    std::cerr << "  (" << source.get_package().get_name()
-			      << " " << source.get_name()
-			      << " is not installed)" << std::endl;
+		    msg << "  (" << (*si).get_package().get_name()
+			<< " " << (*si).get_name()
+			<< " is installed)" << std::endl;
 
-		abort();
+		throw ResolverInternalErrorException(msg.str());
 	      }
 
 	    imm::map<package, action> conflict;
@@ -2097,7 +2103,7 @@ private:
 
 		add_conflict(conflict);
 
-		return;
+		dead_end = true;
 	      }
 	    else if(num_successors == 1)
 	      {
@@ -2111,7 +2117,7 @@ private:
 		generate_successors(curr, *bi, conflict,
 				    real_generator(v));
 
-		assert(v.size() == 1);
+		eassert(v.size() == 1);
 
 		curr = v.back();
 		done = false;
@@ -2119,6 +2125,11 @@ private:
 	  }
       }
 
+    // Discard this node if there is no solution to at least one
+    // dependency.
+    if(dead_end)
+      return;
+
     // In the course of forcing dependencies, we might have actually
     // arrived at a solution, in which case we should just enqueue it
     // and stop (a full solution has no successors to generate).
@@ -2197,7 +2208,15 @@ public:
     // Find all the broken deps.
     for(typename PackageUniverse::broken_dep_iterator bi=universe.broken_begin();
 	!bi.end(); ++bi)
-      initial_broken.insert(*bi);
+      {
+	dep bd(*bi);
+
+	eassert(bd.broken_under(solution::root_node(initial_broken,
+						    universe,
+						    weights)));
+
+	initial_broken.insert(bd);
+      }
   }
 
   ~generic_problem_resolver()
@@ -2273,7 +2292,7 @@ public:
    */
   void set_version_score(const version &ver, int score)
   {
-    assert(ver.get_id()<universe.get_version_count());
+    eassert(ver.get_id()<universe.get_version_count());
     weights.version_scores[ver.get_id()]=score;
   }
 
@@ -2282,14 +2301,14 @@ public:
    */
   void add_version_score(const version &ver, int score)
   {
-    assert(ver.get_id()<universe.get_version_count());
+    eassert(ver.get_id()<universe.get_version_count());
     weights.version_scores[ver.get_id()]+=score;
   }
 
   /** \return the score of the version ver. */
   int get_version_score(const version &ver)
   {
-    assert(ver.get_id()<universe.get_version_count());
+    eassert(ver.get_id()<universe.get_version_count());
     return weights.version_scores[ver.get_id()];
   }
 
@@ -2375,7 +2394,7 @@ public:
   /** Harden the given dependency. */
   void harden(const dep &d, undo_group *undo = NULL)
   {
-    assert(d.is_soft());
+    eassert(d.is_soft());
 
     std::pair<typename std::set<dep>::const_iterator, bool>
       insert_result = user_hardened.insert(d);
@@ -2479,6 +2498,23 @@ public:
       }
   }
 
+  /** Remove all dependency-related information from a set of actions;
+   *  used to insert conflicts that shouldn't have dependency tags.
+   */
+  static imm::map<package, action>
+  strip_dep_info(const imm::map<package, action> &actmap)
+  {
+    imm::map<package, action> rval;
+
+    for(typename imm::map<package, action>::const_iterator i = actmap.begin();
+	i != actmap.end(); ++i)
+      rval.put(i->first, action(i->second.ver,
+				dep(), false,
+				i->second.id));
+
+    return rval;
+  }
+
   /** Cancel any find_next_solution call that is executing in the
    *  background.  If no such call is executing, then the next call
    *  will immediately be cancelled.
@@ -2671,7 +2707,7 @@ public:
 		// everything or extend everything so a conflict can
 		// represent it.
 		if(minimized.get_unresolved_soft_deps().empty())
-		  add_conflict(minimized.get_actions());
+		  add_conflict(strip_dep_info(minimized.get_actions()));
 		else
 		  generated_solutions.push_back(minimized);
 
@@ -2706,7 +2742,7 @@ public:
     if(max_steps==0)
       throw NoMoreTime();
 
-    assert(open.empty());
+    eassert(open.empty());
 
     finished=true;
 
