@@ -9,7 +9,7 @@
 
 #include "vscreen/config/keybindings.h"
 
-void load_colors(std::string group, bool usetheme);
+void load_styles(std::string group, bool usetheme);
 //  Loads in color definitions from the given group.
 
 void load_bindings(std::string group, keybindings *toload, bool usetheme);
