@@ -8,9 +8,10 @@
 #include "pkg_columnizer.h"
 #include "ui.h"
 
-#include <generic/config_signal.h>
-#include <generic/apt.h>
+#include <generic/apt/config_signal.h>
+#include <generic/apt/apt.h>
 
+#include <vscreen/transcode.h>
 #include <vscreen/vs_table.h>
 
 #include <apt-pkg/error.h>
@@ -84,7 +85,14 @@ std::list<package_view_item> *load_pkgview(std::string cfggroup)
 	  else
 	    colinf=subtree.Find("Columns");
 
-	  tmp.columns=parse_columns(colinf,
+	  std::wstring wcolinf;
+	  if(!transcode(colinf.c_str(), wcolinf))
+	    {
+	      _error->Error(_("Couldn't parse layout: encoding error in column descriptor"));
+	      delete rval;
+	      return NULL;
+	    }
+	  tmp.columns=parse_columns(wcolinf,
 				    pkg_item::pkg_columnizer::parse_column_type,
 				    pkg_item::pkg_columnizer::defaults);
 	  if(!tmp.columns)
@@ -187,10 +195,10 @@ std::list<package_view_item> *load_pkgview(std::string cfggroup)
 	    }
 	}
 
-      if(subtree.Exists("Color"))
-	tmp.bg=get_color(subtree.Find("Color"));
-      else
-	tmp.bg=get_color("DefaultWidgetBackground");
+      if(subtree.Exists("Style"))
+	{
+	  tmp.st=get_style(subtree.Find("Style"));
+	}
 
       tmp.visible=subtree.FindB("Visible", true);
 
