@@ -26,8 +26,6 @@
 #include "pkg_item.h"
 #include "vscreen/config/column_definition.h"
 
-#include <apt-pkg/init.h> // For the APT version.
-
 class pkg_item::pkg_columnizer:public column_generator
 {
   class pkg_genheaders;
@@ -58,13 +56,7 @@ public:
 	      autoset, tagged, archive, sizechange,
 
               progname, progver, brokencount, diskusage, downloadsize,
-	      pin_priority,
-              hostname,
-#if APT_PKG_MAJOR >= 3 && APT_PKG_MINOR >= 5
-	      trust_state, numtypes};
-#else
-	      numtypes};
-#endif
+	      pin_priority, hostname, trust_state, numtypes};
   static column_type_defaults defaults[numtypes];
   static const char *column_names[numtypes];
 
@@ -76,7 +68,7 @@ public:
   static void setup_columns(bool force_update=false);
   // This reads and sets up the necessary information about how to format the
   // display of packages.
-  static std::string format_column_names(unsigned int width);
+  static std::wstring format_column_names(unsigned int width);
   // Returns a string which can serve as a header for the column-name
   // information for a screen of the given width.
 
