@@ -1,6 +1,6 @@
 // pkg_subtree.cc
 //
-//  Copyright 1999-2002 Daniel Burrows
+//  Copyright 1999-2005 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -21,33 +21,32 @@
 
 #include "pkg_subtree.h"
 
-#include <generic/apt.h>
+#include <generic/apt/apt.h>
 
 #include <vscreen/vs_tree.h>
 
-#include "pkg_sortpolicy.h"
-
-void pkg_subtree::paint(vs_tree *win, int y, bool hierarchical)
+void pkg_subtree::paint(vs_tree *win, int y, bool hierarchical,
+			const style &st)
 {
   vs_subtree<pkg_tree_node>::paint(win, y, hierarchical, name);
 }
 
-const char *pkg_subtree::tag() const
+const wchar_t *pkg_subtree::tag()
 {
   return name.c_str();
 }
 
-const char *pkg_subtree::label() const
+const wchar_t *pkg_subtree::label()
 {
   return name.c_str();
 }
 
-bool pkg_subtree::dispatch_char(chtype ch, vs_tree *owner)
+bool pkg_subtree::dispatch_key(const key &k, vs_tree *owner)
 {
-  if(pkg_tree_node::dispatch_char(ch, owner))
+  if(pkg_tree_node::dispatch_key(k, owner))
     return true;
   else
-    return vs_subtree<pkg_tree_node>::dispatch_char(ch, owner);
+    return vs_subtree<pkg_tree_node>::dispatch_key(k, owner);
 }
 
 void pkg_subtree::select(undo_group *undo)
@@ -123,11 +122,11 @@ void pkg_subtree::set_auto(bool isauto, undo_group *undo)
 void pkg_subtree::highlighted(vs_tree *win)
 {
   if(info_signal)
-    (*info_signal)(string(description));
+    (*info_signal)(description);
 }
 
 void pkg_subtree::unhighlighted(vs_tree *win)
 {
   if(info_signal)
-    (*info_signal)("");
+    (*info_signal)(L"");
 }
