@@ -329,10 +329,7 @@ column_disposition pkg_ver_columnizer::setup_column(int type)
 
       break;
     case description:
-      if(ver.end())
-	return column_disposition("", 0);
-
-      return column_disposition(apt_package_records->Lookup(ver.FileList()).ShortDesc(), 0);
+      return column_disposition(get_short_description(ver), 0);
     case maintainer:
       if(ver.end())
 	return column_disposition("", 0);
@@ -736,11 +733,10 @@ bool pkg_ver_item::dispatch_key(const key &k, vs_tree *owner)
 
       struct sigaction oldact;
       struct sigaction act;
+
+      memset(&act,0,sizeof(act));
       act.sa_handler = SIG_DFL;
-      act.sa_sigaction = 0;
       sigemptyset(&act.sa_mask);
-      act.sa_flags = 0;
-      act.sa_restorer = 0;
 
       sigaction(SIGCONT, &act, &oldact);
 
