@@ -1,6 +1,6 @@
 // pkg_ver_item.h (This is -*-c++-*-)
 //
-//  Copyright 1999,2000,2001 Daniel Burrows
+//  Copyright 1999-2002, 2004-2005 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,9 @@
 #ifndef PKG_VER_ITEM_H
 #define PKG_VER_ITEM_H
 
-#include "../config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include "apt_info_tree.h"
 
@@ -37,23 +39,28 @@
 class pkg_ver_item:public pkg_tree_node
 {
   pkgCache::VerIterator version;
+  /** Stores the name of this version to avoid problems that can arise
+   *  with transcode().
+   */
+  std::wstring version_name;
 
   bool show_pkg_name;
 
   pkg_signal *sig;
 public:
   pkg_ver_item(const pkgCache::VerIterator &_version, pkg_signal *_sig,
-	       bool _show_pkg_name=false)
-    :version(_version), show_pkg_name(_show_pkg_name), sig(_sig) {}
+	       bool _show_pkg_name=false);
 
   pkgCache::PkgIterator get_package() const {return version.ParentPkg();}
   const pkgCache::VerIterator &get_version() const {return version;}
 
-  virtual int get_normal_attr();
-  virtual void paint(vs_tree *win, int y, bool hierarchical);
+  virtual style get_normal_style();
+  virtual style get_highlighted_style();
+  virtual void paint(vs_tree *win, int y, bool hierarchical,
+		     const style &st);
 
-  virtual const char *tag() const;
-  virtual const char *label() const;
+  virtual const wchar_t *tag();
+  virtual const wchar_t *label();
 
   virtual void select(undo_group *undo);
   virtual void hold(undo_group *undo);
@@ -70,11 +77,21 @@ public:
 
   void show_information();
 
-  bool dispatch_char(chtype ch, vs_tree *owner);
+  bool dispatch_key(const key &k, vs_tree *owner);
 
   pkg_ver_item *get_sig();
 
-  static int ver_attr(pkgCache::VerIterator version, int normal_attr);
+  static style ver_style(pkgCache::VerIterator version,
+			 bool highlighted);
+
+
+  // Menu redirections:
+  bool package_forbid_enabled();
+  bool package_forbid();
+  bool package_changelog_enabled();
+  bool package_changelog();
+  bool package_information_enabled();
+  bool package_information();
 };
 
 class versort:public sortpolicy
@@ -89,7 +106,7 @@ public:
     return _system->VS->CmpVersion(item1->get_version().VerStr(), item2->get_version().VerStr());
   }
 
-  bool operator()(const vs_treeitem *item1, const vs_treeitem *item2) const
+  bool operator()(vs_treeitem *item1, vs_treeitem *item2)
   {
     // FIXME: this is horrible.
     const pkg_ver_item *pitem1=dynamic_cast<const pkg_ver_item *>(item1);
@@ -105,13 +122,13 @@ public:
 typedef pkg_item_with_subtree<pkg_ver_item, versort> pkg_vertree;
 class pkg_vertree_generic:public vs_subtree<pkg_ver_item, versort>
 {
-  std::string name;
+  std::wstring name;
 public:
-  pkg_vertree_generic(std::string _name, bool _expanded):vs_subtree<pkg_ver_item, versort>(_expanded),name(_name) {}
-  void paint(vs_tree *win, int y, bool hierarchical)
+  pkg_vertree_generic(std::wstring _name, bool _expanded):vs_subtree<pkg_ver_item, versort>(_expanded),name(_name) {}
+  void paint(vs_tree *win, int y, bool hierarchical, const style &st)
   {vs_subtree<pkg_ver_item, versort>::paint(win, y, hierarchical, name);}
-  const char *tag() const {return name.c_str();}
-  const char *label() const {return name.c_str();}
+  const wchar_t *tag() {return name.c_str();}
+  const wchar_t *label() {return name.c_str();}
 };
 
 // The following policy will make each package given to it into a
@@ -130,10 +147,18 @@ class pkg_ver_screen:public apt_info_tree
 protected:
   virtual vs_treeitem *setup_new_root(const pkgCache::PkgIterator &pkg,
 				      const pkgCache::VerIterator &ver);
-public:
   pkg_ver_screen(const pkgCache::PkgIterator &pkg);
+public:
+  static ref_ptr<pkg_ver_screen> create(const pkgCache::PkgIterator &pkg)
+  {
+    ref_ptr<pkg_ver_screen> rval(new pkg_ver_screen(pkg));
+    rval->decref();
+    return rval;
+  }
 };
 
+typedef ref_ptr<pkg_ver_screen> pkg_ver_screen_ref;
+
 void setup_package_versions(const pkgCache::PkgIterator &pkg, pkg_vertree *tree, pkg_signal *sig);
 void setup_package_versions(const pkgCache::PkgIterator &pkg, pkg_vertree_generic *tree, pkg_signal *sig);
 // Adds all versions of a package to the given tree.
