@@ -9,8 +9,8 @@
 #include "pkg_ver_item.h"
 #include "ui.h"
 
-#include <generic/apt.h>
-#include <generic/infer_reason.h>
+#include <generic/apt/apt.h>
+#include <generic/apt/infer_reason.h>
 
 #include <vscreen/config/colors.h>
 #include <vscreen/fragment.h>
@@ -28,14 +28,14 @@ fragment *depname_frag(pkgCache::DepIterator dep)
   switch(dep->Type)
     {
     case pkgCache::Dep::Depends: return text_fragment(_("depends on"),
-						      A_BOLD);
+						      style_attrs_on(A_BOLD));
     case pkgCache::Dep::PreDepends: return text_fragment(_("pre-depends on"),
-							 A_BOLD);
+							 style_attrs_on(A_BOLD));
     case pkgCache::Dep::Suggests: return text_fragment(_("suggests"));
     case pkgCache::Dep::Recommends: return text_fragment(_("recommends"),
-							 A_BOLD);
+							 style_attrs_on(A_BOLD));
     case pkgCache::Dep::Conflicts: return text_fragment(_("conflicts with"),
-							A_BOLD);
+							style_attrs_on(A_BOLD));
     case pkgCache::Dep::Replaces: return text_fragment(_("replaces"));
     case pkgCache::Dep::Obsoletes: return text_fragment(_("obsoletes"));
     }
@@ -43,7 +43,7 @@ fragment *depname_frag(pkgCache::DepIterator dep)
   // Untranslated (internal error that will only happen if things go
   // entirely wonky, and I want to be able to understand it if it
   // appears)
-  return text_fragment("has an invalid dependency type!", get_color("Error"));
+  return text_fragment("has an invalid dependency type!", get_style("Error"));
 }
 
 /** Compare two packages by name */
@@ -137,15 +137,15 @@ fragment *prvfrag(pkgCache::PkgIterator pkg,
 	 (currver.end() || provided_curr) &&
 	 (provided_cand || provided_curr))
 	fragments.push_back(text_fragment(P->Name(),
-					  pkg_item::pkg_attr(*P, A_NORMAL)));
+					  pkg_item::pkg_style(*P, false)));
       else if(provided_cand || provided_curr)
 	{
 	  pkgCache::VerIterator &pv=provided_cand?candver:currver;
 
-	  fragments.push_back(attr_fragment(fragf("%s %s",
-						  P->Name(),
-						  pv.VerStr()),
-					    pkg_ver_item::ver_attr(pv, A_NORMAL)));
+	  fragments.push_back(style_fragment(fragf("%s %s",
+						   P->Name(),
+						   pv.VerStr()),
+					     pkg_ver_item::ver_style(pv, false)));
 	}
       else
 	// Bail and print EVERYTHING IN SIGHT...not very efficiently, either.
@@ -153,10 +153,10 @@ fragment *prvfrag(pkgCache::PkgIterator pkg,
 	  for(set<pkgCache::VerIterator>::const_iterator i=providing_versions.begin();
 	      i!=providing_versions.end(); ++i)
 	    if(i->ParentPkg()==*P)
-	      fragments.push_back(attr_fragment(fragf("%s %s",
-						      P->Name(),
-						      i->VerStr()),
-						pkg_ver_item::ver_attr(*i, A_NORMAL)));
+	      fragments.push_back(style_fragment(fragf("%s %s",
+						       P->Name(),
+						       i->VerStr()),
+						 pkg_ver_item::ver_style(*i, false)));
 	}
     }
 
@@ -164,7 +164,7 @@ fragment *prvfrag(pkgCache::PkgIterator pkg,
     return fragf("");
   else
     return fragf(_(" (provided by %F)"),
-		 join_fragments(fragments, ", "));
+		 join_fragments(fragments, L", "));
 }
 
 /** Generate a fragment describing the given dependency iterator. */
@@ -176,7 +176,7 @@ fragment *dep_singlefrag(pkgCache::PkgIterator pkg,
   pkgCache::VerIterator instver=(*apt_cache_file)[pkg].InstVerIter(*apt_cache_file);
 
   if(!dep.TargetVer())
-    verfrag=text_fragment("", A_NORMAL);
+    verfrag=text_fragment("");
   else
     {
       // Figure out the state of the versioned dep.
@@ -186,7 +186,7 @@ fragment *dep_singlefrag(pkgCache::PkgIterator pkg,
       // it is satisfied but won't be, and "installing" if it is not
       // satisfied and will be.
 
-      int verattr=A_NORMAL;
+      style verstyle;
 
       bool matches_now=!pkg.CurrentVer().end() &&
 	_system->VS->CheckDep(pkg.CurrentVer().VerStr(),
@@ -200,21 +200,19 @@ fragment *dep_singlefrag(pkgCache::PkgIterator pkg,
       if(matches_now)
 	{
 	  if(matches_inst)
-	    verattr=A_BOLD;
+	    verstyle=style_attrs_on(A_BOLD);
 	  else
-	    verattr=get_color("PkgToRemove");
+	    verstyle=get_style("PkgToRemove");
 	}
       else
 	{
 	  if(matches_inst)
-	    verattr=get_color("PkgToInstall");
-	  else
-	    verattr=A_NORMAL;
+	    verstyle=get_style("PkgToInstall");
 	}
 
       verfrag=fragf(" (%s %F)",
 		    dep.CompType(),
-		    text_fragment(dep.TargetVer(), verattr));
+		    text_fragment(dep.TargetVer(), verstyle));
     }
 
   // Display a note if the package that is depended upon is not in
@@ -237,8 +235,7 @@ fragment *dep_singlefrag(pkgCache::PkgIterator pkg,
 
   return fragf("%F%s%F%F%s",
 	       text_fragment(dep.TargetPkg().Name(),
-			     pkg_item::pkg_attr(dep.TargetPkg(),
-						A_NORMAL)),
+			     pkg_item::pkg_style(dep.TargetPkg(), false)),
 	       sec.empty() || sec=="main"?"":(" ["+sec+']').c_str(),
 	       verfrag,
 	       prvfrag(dep.TargetPkg(),
@@ -277,7 +274,7 @@ fragment *dep_or_frag(pkgCache::PkgIterator pkg,
 
   return fragf(_("%F%s %F %F"),
 	       text_fragment(dep.ParentPkg().Name(),
-			     pkg_item::pkg_attr(dep.ParentPkg(), A_NORMAL)),
+			     pkg_item::pkg_style(dep.ParentPkg(), false)),
 	       sec.empty() || sec=="main"?"":(" ["+sec+']').c_str(),
 	       depname_frag(dep),
 	       sequence_fragment(fragments));
@@ -312,7 +309,7 @@ fragment *reasonsfrag(pkgCache::PkgIterator pkg, set<reason> &reasons)
 	  fragment *itemtext=dep_or_frag(pkg, i->dep);
 
 	  fragments.push_back(sequence_fragment(text_fragment("  * ",
-							      get_color("Bullet")),
+							      get_style("Bullet")),
 						indentbox(0, 4, flowbox(itemtext)),
 						NULL));
 	}
