@@ -8,7 +8,8 @@
 #define REASON_FRAGMENT_H
 
 #include <apt-pkg/pkgcache.h>
-#include <generic/infer_reason.h>
+
+#include <generic/apt/infer_reason.h>
 
 class fragment;
 
