@@ -448,6 +448,14 @@ public:
     return rval;
   }
 
+  void paint(const style &st)
+  {
+    if(apt_cache_file == NULL)
+      update();
+
+    vs_multiplex::paint(st);
+  }
+
   void update()
   {
     ref_ptr<solution_examiner> tmpref(this);
@@ -455,6 +463,7 @@ public:
     if(!apt_cache_file)
       {
 	set_static_root(transcode(_("The package cache is not available.")));
+	set_active_dep(aptitude_resolver_dep());
 	return;
       }
 
