@@ -1,6 +1,6 @@
 // vs_progress.h   -*-c++-*-
 //
-//  Copyright 2000 Daniel Burrows
+//  Copyright 2000, 2004-2005 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -29,14 +29,25 @@
 
 class vs_progress:public vscreen_widget, public OpProgress
 {
+protected:
+  vs_progress();
 public:
-  virtual void paint();
+  static ref_ptr<vs_progress> create()
+  {
+    return new vs_progress;
+  }
+
+  virtual void paint(const style &st);
   virtual void Update();
   virtual void Done();
 
-  size size_request() {return size(40, 1);}
+  int width_request();
+  int height_request(int w);
+
   bool get_cursorvisible();
   point get_cursorloc();
 };
 
+typedef ref_ptr<vs_progress> vs_progress_ref;
+
 #endif
