@@ -1,15 +1,32 @@
 // vs_menu.h  -*-c++-*-
 //
+//   Copyright (C) 2000-2005 Daniel Burrows
+//
+//   This program is free software; you can redistribute it and/or
+//   modify it under the terms of the GNU General Public License as
+//   published by the Free Software Foundation; either version 2 of
+//   the License, or (at your option) any later version.
+//
+//   This program is distributed in the hope that it will be useful,
+//   but WITHOUT ANY WARRANTY; without even the implied warranty of
+//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+//   General Public License for more details.
+//
+//   You should have received a copy of the GNU General Public License
+//   along with this program; see the file COPYING.  If not, write to
+//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+//   Boston, MA 02111-1307, USA.
+//
 //  A nice menu with selectable entries.  (fairly basic atm)
 
 #ifndef VS_MENU_H
 #define VS_MENU_H
 
-#include "bool_marshal.h"
 #include "vscreen_widget.h"
 #include "config/keybindings.h"
 
-#include "slotarg.h"
+#include <generic/util/bool_accumulate.h>
+#include <generic/util/slotarg.h>
 
 #include <vector>
 
@@ -19,10 +36,10 @@
 class vs_menu_item
 {
   // The text displayed in the menu entry
-  std::string title;
+  std::wstring title;
 
   // A string describing the item's function
-  std::string description;
+  std::wstring description;
 
   // The keybinding whose definition (in the GLOBAL bindings list) is
   // displayed to the right of the menu entry.
@@ -32,19 +49,19 @@ class vs_menu_item
   chtype hotkey;
 public:
   // Infers the hotkey from the title
-  vs_menu_item(const std::string &_title, const std::string &_binding,
-	       const std::string &_description);
+  vs_menu_item(const std::wstring &_title, const std::string &_binding,
+	       const std::wstring &_description);
 
-  std::string get_title() {return title;}
-  std::string get_binding() {return binding;}
-  std::string get_description() {return description;}
-  chtype get_hotkey() {return hotkey;}
+  std::wstring get_title() const {return title;}
+  std::string get_binding() const {return binding;}
+  std::wstring get_description() const {return description;}
+  chtype get_hotkey() const {return hotkey;}
 
   /** The canonical way to test whether an item is really enabled. */
-  bool is_enabled();
+  bool is_enabled() const;
 
   /** Emitted when the menu item is selected. */
-  SigC::Signal0<void> selected;
+  sigc::signal0<void> selected;
 
   /** Emitted to test whether the menu item should be displayed as "active".
    *
@@ -52,7 +69,7 @@ public:
    *  "selected" is non-empty.  Otherwise, the return value of the signal
    *  is used.
    */
-  SigC::Signal0<bool, MarshalOr> enabled;
+  sigc::signal0<bool, accumulate_or> enabled;
 };
 
 #define VS_MENU_NOP NULL
@@ -66,33 +83,28 @@ public:
   // VS_MENU_END: the last item in this information block
   enum item_types {VS_MENU_ITEM, VS_MENU_SEPARATOR, VS_MENU_END} item_type;
 
+  /** item_name and item_description are multibyte representations. */
   const char *item_name, *item_binding, *item_description;
 
   // How to communicate with the outside world..
-  Slot0Arg item_slot;
+  slot0arg item_slot;
 
   // For activation
-  SlotArg<SigC::Slot0<bool> >  item_enabled;
+  slotarg<sigc::slot0<bool> >  item_enabled;
 
   vs_menu_info(item_types type, const char *name, const char *binding,
-	       const char *description, SigC::Slot0<void> slot);
+	       const char *description, sigc::slot0<void> slot);
 
   vs_menu_info(item_types type, const char *name, const char *binding,
-	       const char *description, SigC::Slot0<void> *slot);
+	       const char *description, sigc::slot0<void> *slot);
 
   vs_menu_info(item_types type, const char *name, const char *binding,
-	       const char *description, SigC::Slot0<void> slot,
-	       SigC::Slot0<bool> enabled);
+	       const char *description, sigc::slot0<void> slot,
+	       sigc::slot0<bool> enabled);
 
   vs_menu_info(item_types type, const char *name, const char *binding,
-	       const char *description, SigC::Slot0<void> *slot,
-	       SigC::Slot0<bool> enabled);
-
-  // In this form, it's useful to bind in bool-returning signals (eg,
-  // to discard all slots after one returns true)
-  vs_menu_info(item_types type, const char *name, const char *binding,
-	       const char *description, SigC::Slot0<bool> slot,
-	       SigC::Slot0<bool> enabled);
+	       const char *description, sigc::slot0<void> *slot,
+	       sigc::slot0<bool> enabled);
 
   vs_menu_info(item_types type);
 };
@@ -111,14 +123,22 @@ class vs_menu:public vscreen_widget
   /** The location of the cursor, or items.size() if no item is selected. */
   itemlist::size_type cursorloc;
 
+  /** The first visible item in the menu. */
+  itemlist::size_type startloc;
+
+  /** The minimum width of this menu. */
+  int min_width;
+
   // connected to "shown"
   void appear();
 
   // connected to "hidden"
   void disappear();
 
-  // (cache the requested width, since it's O(n) to find it)
-  int req_width;
+  /** Update the starting location from the current height and cursor
+   *  location.
+   */
+  void update_startloc();
 
   /** Returns \b true iff the given item is selectable. */
   bool selectable(itemlist::size_type pos);
@@ -157,38 +177,69 @@ class vs_menu:public vscreen_widget
   void sanitize_cursor(bool forward);
 
 protected:
-  virtual bool handle_char(chtype ch);
-public:
-  // Initialize a blank menu.
-  vs_menu();
+  virtual bool handle_key(const key &k);
 
-  // Deletes the items it holds!
-  ~vs_menu();
+  /** Create a blank menu. */
+  vs_menu();
 
   // Initialize a menu from a block of information.  If there is no
   // VS_MENU_END in the block, RANDOM ERRORS WILL OCCUR!!
   vs_menu(int x, int y, int w, vs_menu_info *inf);
+public:
+  static ref_ptr<vs_menu> create()
+  {
+    ref_ptr<vs_menu> rval(new vs_menu);
+    rval->decref();
+    return rval;
+  }
+
+  static ref_ptr<vs_menu> create(int x, int y, int w, vs_menu_info *inf)
+  {
+    ref_ptr<vs_menu> rval(new vs_menu(x, y, w, inf));
+    rval->decref();
+    return rval;
+  }
+
+  // Deletes the items it holds!
+  ~vs_menu();
 
   bool get_cursorvisible();
   point get_cursorloc();
-  size size_request();
+
+  int width_request();
+  int height_request(int width);
+
   void append_item(vs_menu_item *newitem);
   void remove_item(vs_menu_item *item);
 
+  /** Move the selection up, as if Up had been pressed. */
+  void move_selection_up();
+
+  /** Move the selection down, as if Down had been pressed. */
+  void move_selection_down();
+
+  /** Move the selection to the top of the menu, as if Home had been pressed. */
+  void move_selection_top();
+
+  /** Move the selection to the bottom of the menu, as if End had been pressed. */
+  void move_selection_bottom();
+
   virtual bool focus_me();
-  virtual void paint();
+  virtual void paint(const style &st);
   virtual void dispatch_mouse(short id, int x, int y, int z, mmask_t bstate);
 
   // Emitted when an item is highlighted or when the selection "goes away".
   // In the latter case, the argument is NULL.  (happens only when
   // the menu is hidden -- FIXME?)
-  SigC::Signal1<void, vs_menu_item *> item_highlighted;
+  sigc::signal1<void, vs_menu_item *> item_highlighted;
 
   // FIXME: there should be a less hacky way..
-  SigC::Signal0<void> menus_goaway;
+  sigc::signal0<void> menus_goaway;
 
   static keybindings *bindings;
   static void init_bindings();
 };
 
+typedef ref_ptr<vs_menu> vs_menu_ref;
+
 #endif
