@@ -1,6 +1,6 @@
 // vs_minibuf_win.h       -*-c++-*-
 //
-//  Copyright 2000 Daniel Burrows
+//  Copyright 2000-2001, 2004-2005 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -30,34 +30,49 @@
 #include "vscreen.h"
 #include "vscreen_widget.h"
 #include "vs_passthrough.h"
-#include "config/colors.h"
+#include "config/style.h"
 
 #include <list>
 
+#include <sigc++/connection.h>
+
 class vs_minibuf;
 class vs_label;
 class vs_multiplex;
 
 class vs_minibuf_win:public vs_passthrough
 {
-  vs_label *status_lbl, *header;
+  ref_ptr<vs_label> status_lbl, header;
 
-  vscreen_widget *main_widget;
+  vs_widget_ref main_widget;
   // This is displayed in the center of the screen.
 
-  vs_multiplex *status;
+  ref_ptr<vs_multiplex> status;
 
-  SigC::Connection main_destroy_conn;
-public:
+  sigc::connection main_destroy_conn;
+
+protected:
   vs_minibuf_win();
+public:
+  static
+  ref_ptr<vs_minibuf_win> create()
+  {
+    ref_ptr<vs_minibuf_win> rval = new vs_minibuf_win;
+    rval->decref();
+    return rval;
+  }
+
   ~vs_minibuf_win();
 
-  void set_main_widget(vscreen_widget *w);
+  void destroy();
 
-  size size_request();
+  void set_main_widget(const vs_widget_ref &w);
+
+  int width_request();
+  int height_request(int w);
   void layout_me();
 
-  virtual void paint();
+  virtual void paint(const style &st);
 
   void show_header();
   void show_status();
@@ -69,20 +84,21 @@ public:
   // Set the status and header lines of the window, respectively.
   // These routines do NOT call refresh()!
 
-  vscreen_widget *get_focus();
+  vs_widget_ref get_focus();
 
-  static int retr_header_color() {return get_color("ScreenHeaderColor");}
-  static int retr_background_color() {return get_color("DefaultWidgetBackground");}
-  static int retr_status_color() {return get_color("ScreenStatusColor");}
+  static const style &retr_header_style() {return get_style("Header");}
+  static const style &retr_status_style() {return get_style("Status");}
   void display_error(std::string err);
 
-  void add_widget(vscreen_widget *widget);
+  void add_widget(const vs_widget_ref &widget);
   // Adds a widget.  Widgets are automatically shown if they're the first
   // one to be added, otherwise show() should be called.
-  void rem_widget(vscreen_widget *widget);
+  void rem_widget(const vs_widget_ref &widget);
   // Removes a widget
 
   void show_all();
 };
 
+typedef ref_ptr<vs_minibuf_win> vs_minibuf_win_ref;
+
 #endif
