@@ -23,24 +23,27 @@
 #ifndef VS_RADIOGROUP_H
 #define VS_RADIOGROUP_H
 
-#include "vs_togglebutton.h"
+#include "ref_ptr.h"
 
 #include <vector>
 
-#include <sigc++/object.h>
+#include <sigc++/connection.h>
+#include <sigc++/trackable.h>
 
-class vs_radiogroup:public SigC::Object
+class vs_togglebutton;
+
+class vs_radiogroup:public sigc::trackable
 {
   struct item
   {
-    vs_togglebutton *b;
+    ref_ptr<vs_togglebutton> b;
     int id;
 
     // Needed, unfortunately.
-    SigC::Connection destroyed_conn, pressed_conn;
+    sigc::connection destroyed_conn, pressed_conn;
 
-    item(vs_togglebutton *_b, int _id,
-	 const SigC::Connection &_dconn, const SigC::Connection &_pconn)
+    item(const ref_ptr<vs_togglebutton> &_b, int _id,
+	 const sigc::connection &_dconn, const sigc::connection &_pconn)
       :b(_b), id(_id), destroyed_conn(_dconn), pressed_conn(_pconn) {}
   };
 
@@ -55,19 +58,29 @@ class vs_radiogroup:public SigC::Object
   // The argument is the *index* of the button.
   void button_pressed(itemlist::size_type index);
 public:
-  vs_radiogroup():selected(items.max_size()) {}
+  vs_radiogroup();
   ~vs_radiogroup();
 
-  void add_button(vs_togglebutton *b, int id);
-  void rem_button(vs_togglebutton *b);
+  void add_button(const ref_ptr<vs_togglebutton> &b, int id);
+  void rem_button(const ref_ptr<vs_togglebutton> &b);
+
+  void rem_button_bare(vs_togglebutton &b);
+
+  /** \return \b true if a button is selected. */
+  bool selection_valid();
+
+  /** \return the id of the selected button, if the selection is valid. */
+  int get_selected();
 
-  int get_selected() {return items[selected].id;}
   // Selects a button by id.
   void select(int id);
 
+  /** Destroy this radio group. */
+  void destroy();
+
   // Emitted when one of the sub-items is chosen.  (you could also collect
   // the individual button signals; this is just a higher-level view of it)
-  SigC::Signal1<void, int> item_selected;
+  sigc::signal1<void, int> item_selected;
 };
 
 #endif
