@@ -1,6 +1,6 @@
 // vs_staticitem.h    -*-c++-*-
 //
-//  Copyright 2000 Daniel Burrows
+//  Copyright 2000, 2001, 2005 Daniel Burrows
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -26,13 +26,13 @@
 
 class vs_staticitem:public vs_treeitem
 {
-  std::string name,value;
+  std::wstring name,value;
 public:
-  vs_staticitem(std::string _name, std::string _value)
+  vs_staticitem(std::wstring _name, std::wstring _value)
     :vs_treeitem(false),name(_name),value(_value) {}
-  void paint(vs_tree *win, int y, bool hierarchical);
-  const char *tag() const {return value.c_str();}
-  const char *label() const {return value.c_str();}
+  void paint(vs_tree *win, int y, bool hierarchical, const style &st);
+  const wchar_t *tag() {return value.c_str();}
+  const wchar_t *label() {return value.c_str();}
 };
 
 #endif
